/*
pycompatmodule, version 0.1

(c) 2003 Jan ONDREJ (SAL) <ondrejj@salstar.sk>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

There are some system specific functions, which are not in
all versions of python.

*/

#include <Python.h>

#define HAVE_CHROOT 1

#ifdef HAVE_CHROOT
static PyObject *
pycompat_chroot(PyObject *self, PyObject *args)
{
  char *path1 = NULL;
  int res;

  if (!PyArg_ParseTuple(args, "et:chroot",
      Py_FileSystemDefaultEncoding, &path1))
    return NULL;
  Py_BEGIN_ALLOW_THREADS
  res = chroot(path1);
  Py_END_ALLOW_THREADS
  if (res < 0) {
    PyObject *rc = PyErr_SetFromErrnoWithFilename(PyExc_OSError, path1);
    PyMem_Free(path1);
    return rc;
  }
  PyMem_Free(path1);
  Py_INCREF(Py_None);
  return Py_None;
}
#endif

static PyMethodDef PyCompatMethods[] = {
#ifdef HAVE_CHROOT
  {"chroot", pycompat_chroot, METH_VARARGS, "Change root directory"},
#endif
  {NULL, NULL, 0, NULL}
};

void initlibclamav(void)
{
	PyObject *m;
	m=Py_InitModule("pycompat", PyCompatMethods);
}
